@@ -5,7 +5,6 @@
 #  SPDX-License-Identifier: MPL-2.0
 
 """Entry point to the weather provider."""
-
 import datetime
 import re
 from typing import List, Optional, Tuple
@@ -16,17 +15,15 @@ import xarray as xr
 from weather_provider_api.routers.weather.api_models import OutputUnit
 from weather_provider_api.routers.weather.base_models.model import WeatherModelBase
 from weather_provider_api.routers.weather.base_models.source import WeatherSourceBase
-from weather_provider_api.routers.weather.exceptions import (
-    UnknownModelException,
-    UnknownSourceException,
-)
+from weather_provider_api.routers.weather.exceptions import UnknownModelException, UnknownSourceException
 from weather_provider_api.routers.weather.sources.cds.cds import CDS
 from weather_provider_api.routers.weather.sources.knmi.knmi import KNMI
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 
 
 class WeatherController(object):  # pragma: no cover
-    """A Controller Object that can handle any request for the hooked up weather models and format it into any of the
+    """
+    A Controller Object that can handle any request for the hooked up weather models and format it into any of the
     hooked up output formats.
     """
 
@@ -40,14 +37,14 @@ class WeatherController(object):  # pragma: no cover
         source_id: str,
         model_id: str,
         fetch_async: bool,
-        coords: list[list[tuple[float, float]]],
-        begin: datetime.datetime | None = None,
-        end: datetime.datetime | None = None,
-        factors: list[str] | None = None,
+        coords: List[List[Tuple[float, float]]],
+        begin: Optional[datetime.datetime] = None,
+        end: Optional[datetime.datetime] = None,
+        factors: List[str] = None,
     ):
-        """Function to use the requested weather model from the requested source to get specific weather factors for a
+        """
+            Function to use the requested weather model from the requested source to get specific weather factors for a
             specific time and specific location(s)
-
         Args:
             source_id:  The weather source that need to be queried (e.g.: knmi, cds)
             model_id:   The model identifier of the model that needs to be queried (has to be a model that exists within
@@ -135,9 +132,7 @@ class WeatherController(object):  # pragma: no cover
             raise UnknownModelException
 
     @staticmethod
-    def _calculate_polygon_means(
-        coords: List[List[Tuple[float, float]]],
-    ) -> List[Tuple[float, float]]:
+    def _calculate_polygon_means(coords: List[List[Tuple[float, float]]]) -> List[Tuple[float, float]]:
         # Calculating the mean points of polygons containing locations
         coords = [
             (
@@ -149,9 +144,7 @@ class WeatherController(object):  # pragma: no cover
         return coords
 
     @staticmethod
-    def _tuples_to_geo_positions(
-        coords: List[Tuple[float, float]],
-    ) -> List[GeoPosition]:
+    def _tuples_to_geo_positions(coords: List[Tuple[float, float]]) -> List[GeoPosition]:
         # Convert the Tuples in a list to a list of Geo Positions
         coords = [GeoPosition(coordinate[0], coordinate[1]) for coordinate in coords]
         return coords
