@@ -4,13 +4,14 @@
 #  SPDX-FileCopyrightText: 2019-2023 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""KNMI current weather data aggregate fetcher."""
-
+""" KNMI current weather data aggregate fetcher.
+"""
 import copy
 from datetime import datetime
 from typing import List, Optional
 
 import numpy as np
+import structlog
 import xarray as xr
 from dateutil.relativedelta import relativedelta
 
@@ -25,9 +26,13 @@ from weather_provider_api.routers.weather.sources.knmi.utils import (
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 from weather_provider_api.routers.weather.utils.pandas_helpers import coords_to_pd_index
 
+logger = structlog.get_logger(__name__)
+
 
 class ActueleWaarnemingenRegisterModel(WeatherModelBase):
-    """A Weather model aimed at accessing a 24-hour register for the "KNMi Actuele Waarnemingen" dataset."""
+    """
+    A Weather model aimed at accessing a 24-hour register for the "KNMi Actuele Waarnemingen" dataset.
+    """
 
     def is_async(self):
         return self.async_model
@@ -36,7 +41,7 @@ class ActueleWaarnemingenRegisterModel(WeatherModelBase):
         super().__init__()
         self.id = "waarnemingen_register"
         self.name = "KNMI Actuele Waarnemingen - 48 uur register"
-        self.version = ""
+        self.version = None
         self.url = "https://www.knmi.nl/nederland-nu/weer/waarnemingen"
         self.predictive = False
         self.time_step_size_minutes = 10
@@ -69,7 +74,8 @@ class ActueleWaarnemingenRegisterModel(WeatherModelBase):
         end: Optional[np.datetime64],
         weather_factors: List[str] = None,
     ) -> xr.Dataset:
-        """The function that gathers and processes the requested Actuele Waarnemingen Register weather data from the
+        """
+        The function that gathers and processes the requested Actuele Waarnemingen Register weather data from the
         48-hour register and returns it as a Xarray Dataset.
         (The register for this model interprets directly from an HTML page, but the information is also available from
         the data platform. Due to it being rather impractically handled, we stick to the site for now.)
@@ -83,7 +89,7 @@ class ActueleWaarnemingenRegisterModel(WeatherModelBase):
         Returns:
             An Xarray Dataset containing the weather data for the requested period, locations and factors.
 
-        Notes:
+        NOTES:
             As this model only return the current weather data the 'begin' and 'end' values are not actually used.
         """
         updated_weather_factors = self._request_weather_factors(weather_factors)
@@ -91,9 +97,13 @@ class ActueleWaarnemingenRegisterModel(WeatherModelBase):
 
         now = datetime.utcnow()
         if now - relativedelta(days=1) > begin:
-            raw_ds = self.repository.get_48_hour_registry_for_station(station=coords_stn)
+            raw_ds = self.repository.get_48_hour_registry_for_station(
+                station=coords_stn
+            )
         else:
-            raw_ds = self.repository.get_24_hour_registry_for_station(station=coords_stn)
+            raw_ds = self.repository.get_24_hour_registry_for_station(
+                station=coords_stn
+            )
 
         data_dictionary = {
             var_name: (["time", "coord"], var.values)
