@@ -4,23 +4,20 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""-- MODULE --"""
+""" -- MODULE --
 
+"""
 import copy
 from datetime import datetime, time, timedelta
 from typing import List, Union
 
+import structlog
 import xarray as xr
-from loguru import logger
 
 from weather_provider_api.routers.weather.base_models.model import WeatherModelBase
-from weather_provider_api.routers.weather.sources.knmi.client.arome_repository import (
-    HarmonieAromeRepository,
-)
+from weather_provider_api.routers.weather.sources.knmi.client.arome_repository import HarmonieAromeRepository
 from weather_provider_api.routers.weather.sources.knmi.knmi_factors import arome_factors
-from weather_provider_api.routers.weather.utils.date_helpers import (
-    validate_begin_and_end,
-)
+from weather_provider_api.routers.weather.utils.date_helpers import validate_begin_and_end
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 
 
@@ -35,7 +32,8 @@ class HarmonieAromeModel(WeatherModelBase):
         # Pre-work
         super().__init__()
         self.id = "arome"
-        logger.debug(f"Initializing weather model: {self.id}")
+        self.logger = structlog.get_logger(__name__)
+        self.logger.debug(f"Initializing weather model: {self.id}", datetime=datetime.utcnow())
 
         # Setting the model
         self.repository = HarmonieAromeRepository()
@@ -60,7 +58,7 @@ class HarmonieAromeModel(WeatherModelBase):
         self.to_human["temperature"]["convert"] = self.kelvin_to_celsius
 
         # Initialization complete
-        logger.debug(f'The Weather model "{self.id}" was successfully initialized')
+        self.logger.debug(f'The Weather model "{self.id}" was successfully initialized', datetime=datetime.utcnow())
 
     def get_weather(
         self,
@@ -79,32 +77,15 @@ class HarmonieAromeModel(WeatherModelBase):
 
         # Validate the given timeframe
         valid_begin, valid_end = validate_begin_and_end(
-            begin,
-            end,
-            self.repository.first_day_of_repo,
-            self.repository.last_day_of_repo,
+            begin, end, self.repository.first_day_of_repo, self.repository.last_day_of_repo
         )
 
         # Gather the period from the repository
         weather_dataset = self.repository.gather_period(begin=valid_begin, end=valid_end, coordinates=coords)
 
         # Filter the requested factors
-        translated_factors = []
-        if weather_factors is not None:
-            for factor in weather_factors:
-                if factor in arome_factors.keys():
-                    new_factor = arome_factors[factor]
-                elif factor in arome_factors.values():
-                    new_factor = factor
-                else:
-                    new_factor = None
-
-                if new_factor is not None:
-                    translated_factors.append(new_factor)
-
-            for factor in weather_dataset.keys():
-                if not any(item in factor for item in translated_factors):
-                    weather_dataset = weather_dataset.drop(factor)
+        # TODO: Implement
+        # weather_dataset = ...
 
         return weather_dataset
 
