@@ -9,9 +9,10 @@ from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
+import structlog
 from fastapi import HTTPException
-from loguru import logger
-from pytz import UTC
+
+logger = structlog.get_logger(__name__)
 
 
 def parse_datetime(
@@ -59,22 +60,15 @@ def time_unknown(dt: datetime, datetime_string: str):  # pragma: no cover
 
 
 def validate_begin_and_end(
-    start: datetime,
-    end: datetime,
-    data_start: Union[datetime, None] = None,
-    data_end: Union[datetime, None] = None,
+    start: datetime, end: datetime, data_start: Union[datetime, None] = None, data_end: Union[datetime, None] = None
 ):
-    """Checks the given date parameters and replaces them with default values if they aren't valid.
+    """
+    Checks the given date parameters and replaces them with default values if they aren't valid.
     The resulting values are then returned.
     """
-    start = start.astimezone(UTC) if start else None
-    end = end.astimezone(UTC) if end else None
-    data_start = data_start.astimezone(UTC) if data_start else None
-    data_end = data_end.astimezone(UTC) if data_end else None
-
     if data_end is None:
         # Assuming predictions fill in this value, the most recent value for the past is before "now".
-        data_end = datetime.now(UTC)
+        data_end = datetime.utcnow()
 
     if data_start is not None and data_start > start:
         # If the starting moment lies before what can be requested, put it at the moment from which it can be requested
@@ -85,19 +79,50 @@ def validate_begin_and_end(
 
     if start >= data_end:
         raise HTTPException(
-            422,
-            f"Invalid [start] value [{start}]: value lies after last available moment for model ({data_end})",
+            422, f"Invalid [start] value [{start}]: value lies after last available moment for model " f"({data_end})"
         )
     if data_start is not None and end <= data_start:
         raise HTTPException(
-            422,
-            f"Invalid [end] value [{end}]: value lies before first available moment for model ({data_start})",
+            422, f"Invalid [end] value [{end}]: value lies before first available moment for model " f"({data_start})"
         )
 
     if end < start:
-        raise HTTPException(
-            422,
-            f"Invalid [start] and [end] values: [end]({end}) lies before [start]({start})",
-        )
+        raise HTTPException(422, f"Invalid [start] and [end] values: [end]({end}) lies before [start]({start})")
 
     return start, end
+
+
+"""
+def validate_begin_and_end(
+    start: datetime,
+    end: datetime,
+    data_start: datetime = None,
+    data_end: datetime = None,
+):
+    if data_end is None:
+        data_end = (
+            datetime.utcnow()
+        )  # Even predictions are made in the past, so no end time can lie in the future.
+
+    # Ending time needs to be filled and is at most the repo ending time
+    if end is None or end > data_end:
+        end = data_end
+
+    # Ending time needs to lie after the repo starting time as well!
+    if data_start is not None and end <= data_start:
+        end = data_start + timedelta(
+            days=7
+        )  # Set to a default of 7 days after the repo starting time
+
+    # Starting time needs to be filled and has to lie before the ending time
+    if start is None or start >= end:
+        start = end - timedelta(
+            days=7
+        )  # Set to a default of 7 days before the ending time
+
+    # Starting time needs to lie at least at the repo starting time if one is given
+    if data_start is not None and start < data_start:
+        start = data_start
+
+    return start, end
+"""
