@@ -26,7 +26,7 @@ def file_or_text_response(
     model_id: str,
     request: Union[WeatherContentRequestQuery, WeatherContentRequestMultiLocationQuery],
     coords: List[Tuple[float, float]],
-) -> tuple[ScientificJSONResponse | FileResponse, str | None]:
+):
     if response_format == ResponseFormat.json:
         return json_response(unserialized_data, coords)
     elif response_format == ResponseFormat.json_dataset:
@@ -41,8 +41,8 @@ def file_response(
     source_id: str,
     model_id: str,
     request: WeatherContentRequestQuery,
-    coords: list[tuple[float, float]],
-) -> tuple[FileResponse, str]:
+    coords: List[Tuple[float, float]],
+):
     if response_format == ResponseFormat.netcdf4:
         file_path = to_netcdf4(unserialized_data)
         mime = "application/x-netcdf4"
@@ -64,9 +64,7 @@ def file_response(
 
 
 def generate_filename(source_id: str, model_id: str, request: WeatherContentRequestQuery, extension: str):
-    file_name = f"weather_{source_id}_{model_id}_{request.begin}-{request.end}{extension}".replace(" ", "T").replace(
-        ":", ""
-    )
+    file_name = f"weather_{source_id}_{model_id}_{request.begin}-{request.end}{extension}".replace(" ", "T")
     return file_name
 
 
@@ -119,8 +117,8 @@ def get_weather_slice_for_coords(coord, unserialized_data) -> pd.DataFrame:
     # We then switch to a Pandas dataframe
     if isinstance(coord, list):
         coord = coord[0]
-    weather = unserialized_data.sel(lat=coord[0], lon=coord[1], method="nearest")
-    if weather.sizes["time"] == 1:
+    weather = unserialized_data.sel(lat=coord[0], lon=coord[1], method='nearest')
+    if weather.dims["time"] == 1:
         # Because a single moment in time can't be squeezed...
         df = weather.to_dataframe()
     else:
